Class: Nahook::PaginatedResult

Inherits:
Struct
  • Object
show all
Defined in:
lib/nahook/resources/deliveries.rb

Overview

Generic paginated result returned by cursor-paginated list endpoints.

Instance Attribute Summary collapse

Instance Attribute Details

#dataArray<Hash>

Returns the page of results.

Returns:

  • (Array<Hash>)

    the page of results



13
# File 'lib/nahook/resources/deliveries.rb', line 13

PaginatedResult = Struct.new(:data, :next_cursor)

#next_cursorString?

Returns opaque cursor for the next page, or nil if this is the last page. Pass back verbatim into the next list call.

Returns:

  • (String, nil)

    opaque cursor for the next page, or nil if this is the last page. Pass back verbatim into the next list call.



13
# File 'lib/nahook/resources/deliveries.rb', line 13

PaginatedResult = Struct.new(:data, :next_cursor)