Class: Nahook::PaginatedResult
- Inherits:
-
Struct
- Object
- Struct
- Nahook::PaginatedResult
- Defined in:
- lib/nahook/resources/deliveries.rb
Overview
Generic paginated result returned by cursor-paginated list endpoints.
Instance Attribute Summary collapse
-
#data ⇒ Array<Hash>
The page of results.
-
#next_cursor ⇒ String?
Opaque cursor for the next page, or nil if this is the last page.
Instance Attribute Details
#data ⇒ Array<Hash>
Returns the page of results.
13 |
# File 'lib/nahook/resources/deliveries.rb', line 13 PaginatedResult = Struct.new(:data, :next_cursor) |
#next_cursor ⇒ String?
Returns opaque cursor for the next page, or nil if this is the last page. Pass back verbatim into the next list call.
13 |
# File 'lib/nahook/resources/deliveries.rb', line 13 PaginatedResult = Struct.new(:data, :next_cursor) |